==> zio-aws-ec2_2.13-5.19.8.3-sources.jar: zio/aws/ec2/model/EnableFastLaunchRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, ImageId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EnableFastLaunchRequest(
    imageId: ImageId,
    resourceType: Optional[String] = Optional.Absent,
    snapshotConfiguration: Optional[
      zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest
    ] = Optional.Absent,
    launchTemplate: Optional[
      zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest
    ] = Optional.Absent,
    maxParallelLaunches: Optional[Integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest = {
    import EnableFastLaunchRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest
      .builder()
      .imageId(ImageId.unwrap(imageId): java.lang.String)
      .optionallyWith(resourceType.map(value => value: java.lang.String))(
        _.resourceType
      )
      .optionallyWith(
        snapshotConfiguration.map(value => value.buildAwsValue())
      )(_.snapshotConfiguration)
      .optionallyWith(launchTemplate.map(value => value.buildAwsValue()))(
        _.launchTemplate
      )
      .optionallyWith(
        maxParallelLaunches.map(value => value: java.lang.Integer)
      )(_.maxParallelLaunches)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.EnableFastLaunchRequest.ReadOnly =
    zio.aws.ec2.model.EnableFastLaunchRequest.wrap(buildAwsValue())
}
object EnableFastLaunchRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.EnableFastLaunchRequest =
      zio.aws.ec2.model.EnableFastLaunchRequest(
        imageId,
        resourceType.map(value => value),
        snapshotConfiguration.map(value => value.asEditable),
        launchTemplate.map(value => value.asEditable),
        maxParallelLaunches.map(value => value)
      )
    def imageId: ImageId
    def resourceType: Optional[String]
    def snapshotConfiguration: Optional[
      zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest.ReadOnly
    ]
    def launchTemplate: Optional[
      zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest.ReadOnly
    ]
    def maxParallelLaunches: Optional[Integer]
    def getImageId: ZIO[Any, Nothing, ImageId] = ZIO.succeed(imageId)
    def getResourceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("resourceType", resourceType)
    def getSnapshotConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest.ReadOnly
    ] =
      AwsError.unwrapOptionField("snapshotConfiguration", snapshotConfiguration)
    def getLaunchTemplate: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest.ReadOnly
    ] = AwsError.unwrapOptionField("launchTemplate", launchTemplate)
    def getMaxParallelLaunches: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("maxParallelLaunches", maxParallelLaunches)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest
  ) extends zio.aws.ec2.model.EnableFastLaunchRequest.ReadOnly {
    override val imageId: ImageId =
      zio.aws.ec2.model.primitives.ImageId(impl.imageId())
    override val resourceType: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceType())
      .map(value => value: String)
    override val snapshotConfiguration: Optional[
      zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.snapshotConfiguration())
      .map(value =>
        zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest.wrap(value)
      )
    override val launchTemplate: Optional[
      zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.launchTemplate())
      .map(value =>
        zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest
          .wrap(value)
      )
    override val maxParallelLaunches: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.maxParallelLaunches())
      .map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest
  ): zio.aws.ec2.model.EnableFastLaunchRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.7-sources.jar: zio/aws/ec2/model/EnableFastLaunchRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, ImageId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EnableFastLaunchRequest(
    imageId: ImageId,
    resourceType: Optional[String] = Optional.Absent,
    snapshotConfiguration: Optional[
      zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest
    ] = Optional.Absent,
    launchTemplate: Optional[
      zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest
    ] = Optional.Absent,
    maxParallelLaunches: Optional[Integer] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest = {
    import EnableFastLaunchRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest
      .builder()
      .imageId(ImageId.unwrap(imageId): java.lang.String)
      .optionallyWith(resourceType.map(value => value: java.lang.String))(
        _.resourceType
      )
      .optionallyWith(
        snapshotConfiguration.map(value => value.buildAwsValue())
      )(_.snapshotConfiguration)
      .optionallyWith(launchTemplate.map(value => value.buildAwsValue()))(
        _.launchTemplate
      )
      .optionallyWith(
        maxParallelLaunches.map(value => value: java.lang.Integer)
      )(_.maxParallelLaunches)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.EnableFastLaunchRequest.ReadOnly =
    zio.aws.ec2.model.EnableFastLaunchRequest.wrap(buildAwsValue())
}
object EnableFastLaunchRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.EnableFastLaunchRequest =
      zio.aws.ec2.model.EnableFastLaunchRequest(
        imageId,
        resourceType.map(value => value),
        snapshotConfiguration.map(value => value.asEditable),
        launchTemplate.map(value => value.asEditable),
        maxParallelLaunches.map(value => value),
        dryRun.map(value => value)
      )
    def imageId: ImageId
    def resourceType: Optional[String]
    def snapshotConfiguration: Optional[
      zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest.ReadOnly
    ]
    def launchTemplate: Optional[
      zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest.ReadOnly
    ]
    def maxParallelLaunches: Optional[Integer]
    def dryRun: Optional[Boolean]
    def getImageId: ZIO[Any, Nothing, ImageId] = ZIO.succeed(imageId)
    def getResourceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("resourceType", resourceType)
    def getSnapshotConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest.ReadOnly
    ] =
      AwsError.unwrapOptionField("snapshotConfiguration", snapshotConfiguration)
    def getLaunchTemplate: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest.ReadOnly
    ] = AwsError.unwrapOptionField("launchTemplate", launchTemplate)
    def getMaxParallelLaunches: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("maxParallelLaunches", maxParallelLaunches)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest
  ) extends zio.aws.ec2.model.EnableFastLaunchRequest.ReadOnly {
    override val imageId: ImageId =
      zio.aws.ec2.model.primitives.ImageId(impl.imageId())
    override val resourceType: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceType())
      .map(value => value: String)
    override val snapshotConfiguration: Optional[
      zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.snapshotConfiguration())
      .map(value =>
        zio.aws.ec2.model.FastLaunchSnapshotConfigurationRequest.wrap(value)
      )
    override val launchTemplate: Optional[
      zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.launchTemplate())
      .map(value =>
        zio.aws.ec2.model.FastLaunchLaunchTemplateSpecificationRequest
          .wrap(value)
      )
    override val maxParallelLaunches: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.maxParallelLaunches())
      .map(value => value: Integer)
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableFastLaunchRequest
  ): zio.aws.ec2.model.EnableFastLaunchRequest.ReadOnly = new Wrapper(impl)
}
